@@ -43,42 +43,39 @@ Based on parts of the GNU C Library:
 
 #include "s_config.h"
 
-enum nss_status _nss_extrausers_setgrent (void);
-enum nss_status _nss_extrausers_endgrent (void);
-enum nss_status _nss_extrausers_getgrent_r (struct group *gr,
-		char * buffer, size_t buflen,int * errnop);
-enum nss_status _nss_extrausers_getgrnam_r (const char * name, struct group *gr,
-		char * buffer, size_t buflen,int *errnop);
-enum nss_status _nss_extrausers_getgrgid_r (const gid_t gid, struct group *gr,
-		char * buffer, size_t buflen,int *errnop);
+enum nss_status _nss_extrausers_setgrent(void);
+enum nss_status _nss_extrausers_endgrent(void);
+enum nss_status _nss_extrausers_getgrent_r(struct group *gr, char *buffer, size_t buflen, int *errnop);
+enum nss_status _nss_extrausers_getgrnam_r(const char *name, struct group *gr, char *buffer, size_t buflen, int *errnop);
+enum nss_status _nss_extrausers_getgrgid_r(const gid_t gid, struct group *gr, char *buffer, size_t buflen, int *errnop);
 
 static FILE *groupsfile = NULL;
 
 /* from clib/nss */
-static inline char **parse_list(char *line,char *data,size_t datalen,int *errnop) {
+static inline char **parse_list(char *line, char *data, size_t datalen, int *errnop) {
 	char *eol, **list, **p;
 
 	if (line >= data && line < (char *) data + datalen)
 		/* Find the end of the line buffer, we will use the space in DATA after
 		 *        it for storing the vector of pointers.  */
-		eol = strchr (line, '\0') + 1;
+		eol = strchr(line, '\0') + 1;
 	else
 		/* LINE does not point within DATA->linebuffer, so that space is
 		 *        not being used for scratch space right now.  We can use all of
 		 *               it for the pointer vector storage.  */
 		eol = data;
 	/* Adjust the pointer so it is aligned for storing pointers.  */
-	eol += __alignof__ (char *) - 1;
-	eol -= (eol - (char *) 0) % __alignof__ (char *);
+	eol += __alignof__(char *) - 1;
+	eol -= (eol - (char *)0) % __alignof__(char *);
 	/* We will start the storage here for the vector of pointers.  */
-	list = (char **) eol;
+	list = (char **)eol;
 
 	p = list;
 	while (1)
 	{
 		char *elt;
 
-		if ((size_t) ((char *) &p[1] - (char *) data) > datalen)
+		if ((size_t) ((char *)&p[1] - (char *)data) > datalen)
 		{
 			/* We cannot fit another pointer in the buffer.  */
 			*errnop = ERANGE;
@@ -88,7 +85,7 @@ static inline char **parse_list(char *line,char *data,size_t datalen,int *errnop
 			break;
 
 		/* Skip leading white space.  This might not be portable but useful.  */
-		while (isspace (*line))
+		while (isspace(*line))
 			++line;
 
 		elt = line;
@@ -112,23 +109,32 @@ static inline char **parse_list(char *line,char *data,size_t datalen,int *errnop
 	return list;
 }
 
-#define TOCOLON(p,h) {while( *p && *p != ':' ) p++; h=p;if(*p) p++;*h='\0';h--;while(isspace(*h)){*h='\0';h--;}}
+#define TOCOLON(p, h) { \
+	while (*p && *p != ':') \
+		p++; \
+	h=p; \
+	if (*p) \
+		p++; \
+	*h='\0'; h--; \
+	while (isspace(*h)) { \
+		*h='\0'; h--; \
+	} \
+}
 
-static inline enum nss_status g_search(FILE *stream,const char *name,const gid_t gid,struct group * gr, int * errnop,char * buffer, size_t buflen)
-{
-	char *p,*h;
+static inline enum nss_status g_search(FILE *stream, const char *name, const gid_t gid, struct group *gr, int *errnop, char *buffer, size_t buflen) {
+	char *p, *h;
 	gid_t t_gid;
-	char *t_name,*t_passwd;
+	char *t_name, *t_passwd;
 	char **t_mem;
 	off_t last_position;
 
 	last_position = ftello(stream);
 	flockfile(stream);
-	while( 1 )  {
+	while (1)  {
 		buffer[buflen - 1] = '\xff';
-		p = fgets_unlocked(buffer,buflen,stream);
-		if( p == NULL ) {
-			if( feof_unlocked(stream) ) {
+		p = fgets_unlocked(buffer, buflen, stream);
+		if (p == NULL) {
+			if (feof_unlocked(stream)) {
 				funlockfile(stream);
 				*errnop = ENOENT;
 				return NSS_STATUS_NOTFOUND;
@@ -138,53 +144,53 @@ static inline enum nss_status g_search(FILE *stream,const char *name,const gid_t
 				return NSS_STATUS_UNAVAIL;
 			}
 		}
-		h = index(p,'\n');
-		if( buffer[buflen - 1] != '\xff' || h == NULL ) {
+		h = index(p, '\n');
+		if (buffer[buflen - 1] != '\xff' || h == NULL) {
 			funlockfile(stream);
 			*errnop = ERANGE;
 			fseeko(stream, last_position, SEEK_SET);
 			return NSS_STATUS_TRYAGAIN;
 		}
-		while( isspace(*h) && h != p ) {
+		while (isspace(*h) && h != p) {
 			*h = '\0';
 			h--;
 		}
 		/* Ignore comments */
-		if( *p == '#' )
+		if (*p == '#')
 			continue;
 
 		/* extract name */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_name = p;
-		TOCOLON(p,h);
-		if( name && strcmp(name,t_name) != 0)
+		TOCOLON(p, h);
+		if (name && strcmp(name, t_name) != 0)
 			continue;
 		/* passwd (should be "x" or "" or something...) */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_passwd = p;
-		TOCOLON(p,h);
+		TOCOLON(p, h);
 		/* extract gid */
-		t_gid = strtol(p,&h,10);
-		if( *h != ':' ) {
+		t_gid = strtol(p, &h, 10);
+		if (*h != ':') {
 			funlockfile(stream);
 			*errnop = 0;
 			return NSS_STATUS_UNAVAIL;
 		}
-		if( gid != 0 && gid != t_gid ) {
+		if (gid != 0 && gid != t_gid) {
 			continue;
 		}
 		p = h;
 		/* extract members */
 		h++; // Over ':'
-		t_mem = parse_list(h,buffer,buflen,errnop);
-		if( t_mem == NULL ){
+		t_mem = parse_list(h, buffer, buflen, errnop);
+		if (t_mem == NULL){
 			funlockfile(stream);
 			fseeko(stream, last_position, SEEK_SET);
 			return NSS_STATUS_TRYAGAIN;
 		}
-		if( t_gid < MINGID ) {
+		if (t_gid < MINGID) {
 			funlockfile(stream);
 			*errnop = 0;
 			return NSS_STATUS_UNAVAIL;
@@ -200,72 +206,66 @@ static inline enum nss_status g_search(FILE *stream,const char *name,const gid_t
 }
 
 
-enum nss_status _nss_extrausers_setgrent (void) {
-	groupsfile = fopen(GROUPSFILE,"r");
-	if( groupsfile == NULL )
+enum nss_status _nss_extrausers_setgrent(void) {
+	groupsfile = fopen(GROUPSFILE, "r");
+	if (groupsfile == NULL)
 		return NSS_STATUS_UNAVAIL;
 	return NSS_STATUS_SUCCESS;
 }
 
-enum nss_status _nss_extrausers_endgrent (void) {
-	if ( groupsfile != NULL ) {
+enum nss_status _nss_extrausers_endgrent(void) {
+	if (groupsfile != NULL) {
 		fclose(groupsfile);
 		groupsfile = NULL;
 	}
 	return NSS_STATUS_SUCCESS;
 }
 
-enum nss_status _nss_extrausers_getgrent_r (struct group *gr,
-		char * buffer, size_t buflen,int * errnop)
-{
+enum nss_status _nss_extrausers_getgrent_r(struct group *gr, char *buffer, size_t buflen, int *errnop) {
 	*errnop = 0;
-	if ( groupsfile == NULL )
+	if (groupsfile == NULL)
 		return NSS_STATUS_UNAVAIL;
 
-	return g_search(groupsfile,NULL,0,gr,errnop,buffer,buflen);
+	return g_search(groupsfile, NULL, 0, gr, errnop, buffer, buflen);
 }
 
 
-enum nss_status _nss_extrausers_getgrnam_r (const char * name, struct group *gr,
-		char * buffer, size_t buflen,int *errnop)
-{
+enum nss_status _nss_extrausers_getgrnam_r(const char *name, struct group *gr, char *buffer, size_t buflen, int *errnop) {
 	enum nss_status e;
 	FILE *f;
 
 	*errnop = 0;
 
-	if ( gr == NULL || name == NULL )
+	if (gr == NULL || name == NULL)
 		return NSS_STATUS_UNAVAIL;
 
-	f = fopen(GROUPSFILE,"r");
-	if( f == NULL ) {
+	f = fopen(GROUPSFILE, "r");
+	if (f == NULL) {
 		*errnop = errno;
 		return NSS_STATUS_UNAVAIL;
 	}
 
-	e = g_search(f,name,0,gr,errnop,buffer,buflen);
+	e = g_search(f, name, 0, gr, errnop, buffer, buflen);
 	fclose(f);
 	return e;
 }
 
-enum nss_status _nss_extrausers_getgrgid_r (const gid_t gid, struct group *gr,
-		char * buffer, size_t buflen,int *errnop)
-{
+enum nss_status _nss_extrausers_getgrgid_r(const gid_t gid, struct group *gr, char *buffer, size_t buflen, int *errnop) {
 	enum nss_status e;
 	FILE *f;
 	*errnop = 0;
-	if ( gr == NULL )
+	if (gr == NULL)
 		return NSS_STATUS_UNAVAIL;
-	if( gid == 0 || gid < MINGID )
+	if (gid == 0 || gid < MINGID)
 		return NSS_STATUS_NOTFOUND;
 
-	f = fopen(GROUPSFILE,"r");
-	if( f == NULL ) {
+	f = fopen(GROUPSFILE, "r");
+	if (f == NULL) {
 		*errnop = errno;
 		return NSS_STATUS_UNAVAIL;
 	}
 
-	e = g_search(f,NULL,gid,gr,errnop,buffer,buflen);
+	e = g_search(f, NULL, gid, gr, errnop, buffer, buflen);
 	fclose(f);
 	return e;
 }
