@@ -44,18 +44,17 @@ Based on parts of the GNU C Library:
 
 #include "s_config.h"
 
-enum nss_status _nss_extrausers_getpwuid_r(uid_t,struct passwd *,char *, size_t,int *);
-enum nss_status _nss_extrausers_setpwent (void);
-enum nss_status _nss_extrausers_endpwent (void);
-enum nss_status _nss_extrausers_getpwnam_r(const char *,struct passwd *,char *,size_t,int *);
-enum nss_status _nss_extrausers_getpwent_r(struct passwd *, char *, size_t,int *);
+enum nss_status _nss_extrausers_getpwuid_r(uid_t, struct passwd *, char *, size_t, int *);
+enum nss_status _nss_extrausers_setpwent(void);
+enum nss_status _nss_extrausers_endpwent(void);
+enum nss_status _nss_extrausers_getpwnam_r(const char *, struct passwd *, char *, size_t, int *);
+enum nss_status _nss_extrausers_getpwent_r(struct passwd *, char *, size_t, int *);
 
-static enum nss_status p_search(FILE *f,const char *name,const uid_t uid,struct passwd *pw, int *errnop,char *buffer, size_t buflen);
+static enum nss_status p_search(FILE *f, const char *name, const uid_t uid, struct passwd *pw, int *errnop, char *buffer, size_t buflen);
 
-static inline enum nss_status p_search(FILE *f,const char *name,const uid_t uid,struct passwd *pw, int *errnop,char *buffer, size_t buflen)
-{
-#define SANEQUIT {funlockfile(stream);if( f==NULL)  fclose(stream);}
-#define TOCOLON(p,h) { while( *p && *p != ':' ) \
+static inline enum nss_status p_search(FILE *f, const char *name, const uid_t uid, struct passwd *pw, int *errnop, char *buffer, size_t buflen) {
+#define SANEQUIT {funlockfile(stream); if (f==NULL) fclose(stream);}
+#define TOCOLON(p, h) { while (*p && *p != ':') \
 				p++; \
 			h=p; \
 			if(!*p) { \
@@ -68,24 +67,24 @@ static inline enum nss_status p_search(FILE *f,const char *name,const uid_t uid,
 			h--; \
 			}
 	FILE *stream = f;
-	char *p,*h;
+	char *p, *h;
 	uid_t t_uid;
 	gid_t t_gid;
-	char *t_name,*t_passwd,*t_gecos,*t_shell,*t_dir;
+	char *t_name, *t_passwd, *t_gecos, *t_shell, *t_dir;
 
-	if( stream == NULL ) {
-		stream = fopen(USERSFILE,"r");
-		if( stream == NULL ) {
+	if (stream == NULL) {
+		stream = fopen(USERSFILE, "r");
+		if (stream == NULL) {
 			*errnop = errno;
 			return NSS_STATUS_UNAVAIL;
 		}
 	}
 	flockfile(stream);
-	while( 1 ) {
+	while (1) {
 		buffer[buflen - 1] = '\xff';
-		p = fgets_unlocked(buffer,buflen,stream);
-		if( p == NULL ) {
-			if( feof_unlocked(stream) ) {
+		p = fgets_unlocked(buffer, buflen, stream);
+		if (p == NULL) {
+			if (feof_unlocked(stream)) {
 				SANEQUIT
 				*errnop = ENOENT;
 				return NSS_STATUS_NOTFOUND;
@@ -95,75 +94,75 @@ static inline enum nss_status p_search(FILE *f,const char *name,const uid_t uid,
 				return NSS_STATUS_UNAVAIL;
 			}
 		}
-		h = index(p,'\n');
-		if( buffer[buflen - 1] != '\xff' || h == NULL ) {
+		h = index(p, '\n');
+		if (buffer[buflen - 1] != '\xff' || h == NULL) {
 			SANEQUIT
 			*errnop = ERANGE;
 			return NSS_STATUS_TRYAGAIN;
 		}
-		while( isspace(*h) && h != p ) {
+		while (isspace(*h) && h != p) {
 			*h = '\0';
 			h--;
 		}
 		/* Ignore comments */
-		if( *p == '#' )
+		if (*p == '#')
 			continue;
 		/* extract name */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_name = p;
-		TOCOLON(p,h);
-		if( name && strcmp(name,t_name)!=0 )
+		TOCOLON(p, h);
+		if (name && strcmp(name, t_name)!=0)
 			continue;
 		/* passwd (should be "x" or "!!" or something...) */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_passwd = p;
-		TOCOLON(p,h);
+		TOCOLON(p, h);
 		/* extract uid */
-		t_uid = strtol(p,&h,10);
-		if( *h != ':' ) {
+		t_uid = strtol(p, &h, 10);
+		if (*h != ':') {
 			SANEQUIT
 			*errnop = 0;
 			return NSS_STATUS_UNAVAIL;
 		}
-		if( t_uid < MINUID ) {
+		if (t_uid < MINUID) {
 			continue;
 		}
-		if( uid != 0 && uid != t_uid) {
+		if (uid != 0 && uid != t_uid) {
 			continue;
 		}
 		p = ++h;
 		/* extract gid */
-		t_gid = strtol(p,&h,10);
-		if( *h != ':' ) {
+		t_gid = strtol(p, &h, 10);
+		if (*h != ':') {
 			SANEQUIT
 			*errnop = 0;
 			return NSS_STATUS_UNAVAIL;
 		}
 # ifdef USERSGID
-		if( t_gid < MINGID && t_gid != USERSGID ) {
+		if (t_gid < MINGID && t_gid != USERSGID) {
 # else
-		if( t_gid < MINGID ) {
+		if (t_gid < MINGID) {
 # endif
 			continue;
 		}
 		p = ++h;
 		/* extract gecos */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_gecos = p;
-		TOCOLON(p,h);
+		TOCOLON(p, h);
 		/* extract dir */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_dir = p;
-		TOCOLON(p,h);
+		TOCOLON(p, h);
 		/* extract shell */
-		while (isspace (*p))
+		while (isspace(*p))
 			++p;
 		t_shell = p;
-		if( index(p,':') ) {
+		if (index(p, ':') != NULL) {
 			SANEQUIT
 			*errnop = 0;
 			return NSS_STATUS_UNAVAIL;
@@ -182,38 +181,33 @@ static inline enum nss_status p_search(FILE *f,const char *name,const uid_t uid,
 	}
 }
 
-enum nss_status _nss_extrausers_getpwuid_r( uid_t uid, struct passwd *result,
-	char *buf, size_t buflen, int *errnop)
-{
+enum nss_status _nss_extrausers_getpwuid_r(uid_t uid, struct passwd *result, char *buf, size_t buflen, int *errnop) {
 	*errnop = 0;
-	if ( result )
-		return p_search(NULL,NULL,uid,result,errnop,buf,buflen);
+	if (result)
+		return p_search(NULL, NULL, uid, result, errnop, buf, buflen);
 	else
 		return NSS_STATUS_UNAVAIL;
 }
 
-enum nss_status _nss_extrausers_getpwnam_r(const char *name, struct passwd *result,
-		char *buf, size_t buflen, int *errnop)
-{
+enum nss_status _nss_extrausers_getpwnam_r(const char *name, struct passwd *result, char *buf, size_t buflen, int *errnop) {
 	*errnop = 0;
-	if ( result )
-		return p_search(NULL,name,0,result,errnop,buf,buflen);
+	if (result)
+		return p_search(NULL, name, 0, result, errnop, buf, buflen);
 	else
 		return NSS_STATUS_UNAVAIL;
 }
 
 static FILE *usersfile = NULL;
 
-enum nss_status _nss_extrausers_setpwent (void)
-{
+enum nss_status _nss_extrausers_setpwent(void) {
 
-	if ( usersfile != NULL )
+	if (usersfile != NULL)
 	{
 		fclose(usersfile);
 		usersfile = NULL;
 	}
-	usersfile = fopen(USERSFILE,"r");
-	if ( usersfile == NULL )
+	usersfile = fopen(USERSFILE, "r");
+	if (usersfile == NULL)
 	{
 		return NSS_STATUS_UNAVAIL;
 	}
@@ -221,10 +215,9 @@ enum nss_status _nss_extrausers_setpwent (void)
 	return NSS_STATUS_SUCCESS;
 }
 
-enum nss_status _nss_extrausers_endpwent (void)
-{
+enum nss_status _nss_extrausers_endpwent(void) {
 
-	if ( usersfile != NULL )
+	if (usersfile != NULL)
 	{
 		fclose(usersfile);
 		usersfile = NULL;
@@ -232,16 +225,14 @@ enum nss_status _nss_extrausers_endpwent (void)
 	return NSS_STATUS_SUCCESS;
 }
 
-enum nss_status _nss_extrausers_getpwent_r (struct passwd *pw,
-                char * buffer, size_t buflen,int * errnop)
-{
+enum nss_status _nss_extrausers_getpwent_r(struct passwd *pw, char *buffer, size_t buflen, int *errnop) {
 	*errnop = -1;
 
-	if ( pw == NULL )
+	if (pw == NULL)
 		return NSS_STATUS_UNAVAIL;
-	if ( usersfile == NULL )
+	if (usersfile == NULL)
 		return NSS_STATUS_UNAVAIL;
 
-  	return p_search(usersfile,NULL,0,pw,errnop,buffer,buflen);
+  	return p_search(usersfile, NULL, 0, pw, errnop, buffer, buflen);
 }
 
